pub struct ThreadReceiver<T> { /* private fields */ }Expand description
A thread-safe channel receiver for intra-process communication.
This is the receiving half of a ThreadChannel. It can be cloned to create
multiple consumers that receive from the same channel.
Implementations
Sourceimpl<T> ThreadReceiver<T>
impl<T> ThreadReceiver<T>
Sourcepub fn recv(&self) -> Result<T>
pub fn recv(&self) -> Result<T>
Receive a message from the channel.
This method blocks until a message is available.
Errors
Returns IpcError::Closed if the channel has been shutdown or all senders have been dropped.
Sourcepub fn try_recv(&self) -> Result<T>
pub fn try_recv(&self) -> Result<T>
Try to receive a message without blocking.
Errors
IpcError::Closedif the channel has been shutdown or all senders have been dropped.IpcError::WouldBlockif no message is available.
Sourcepub fn recv_timeout(&self, timeout: Duration) -> Result<T>
pub fn recv_timeout(&self, timeout: Duration) -> Result<T>
Receive a message with a timeout.
Errors
IpcError::Closedif the channel has been shutdown or all senders have been dropped.IpcError::Timeoutif the timeout expires before a message is available.
Sourcepub fn capacity(&self) -> Option<usize>
pub fn capacity(&self) -> Option<usize>
Get the capacity of the channel (None for unbounded channels).
Sourcepub fn is_shutdown(&self) -> bool
pub fn is_shutdown(&self) -> bool
Check if the channel has been shutdown.