pub struct ThreadSender<T> { /* private fields */ }Expand description
A thread-safe channel sender for intra-process communication.
This is the sending half of a ThreadChannel. It can be cloned to create
multiple producers that send to the same channel.
Implementations
Sourceimpl<T> ThreadSender<T>
impl<T> ThreadSender<T>
Sourcepub fn send(&self, msg: T) -> Result<()>
pub fn send(&self, msg: T) -> Result<()>
Send a message through the channel.
This method blocks if the channel is bounded and full.
Errors
Returns IpcError::Closed if the channel has been shutdown or all receivers have been dropped.
Sourcepub fn try_send(&self, msg: T) -> Result<()>
pub fn try_send(&self, msg: T) -> Result<()>
Try to send a message without blocking.
Errors
IpcError::Closedif the channel has been shutdown or all receivers have been dropped.IpcError::WouldBlockif the channel is full (bounded channels only).
Sourcepub fn send_timeout(&self, msg: T, timeout: Duration) -> Result<()>
pub fn send_timeout(&self, msg: T, timeout: Duration) -> Result<()>
Send a message with a timeout.
Errors
IpcError::Closedif the channel has been shutdown or all receivers have been dropped.IpcError::Timeoutif the timeout expires before the message can be sent.
Sourcepub fn is_full(&self) -> bool
pub fn is_full(&self) -> bool
Check if the channel is full (always false for unbounded channels).
Sourcepub fn capacity(&self) -> Option<usize>
pub fn capacity(&self) -> Option<usize>
Get the capacity of the channel (None for unbounded channels).
Sourcepub fn is_shutdown(&self) -> bool
pub fn is_shutdown(&self) -> bool
Check if the channel has been shutdown.